@@ -78,7 +78,7 @@ class MainLog(BaseLog):
                     ret = f(*args, **kwargs)
                     end_time = time.time()
                     try:
-                        total_time = end_time - begin_time
+                        total_time = str(int((end_time - begin_time) * 1000))
                         f_code = request.headers.get('User-Agent')
                         self.debug('with_internal_journallog() connection  after:%s', str(total_time))
                         # 接口前置流水日志处理
